# %{ver}, %rel} are provided by the Makefile
%define ver 4.1.0
%define rel 2
%define cairo_ver 1.0.2

Summary: LSB Desktop Test Suites (also see lsb-test-desktop-gtkvts-source)
Name: lsb-test-desktop
Version: %{ver} 
Release: %rel
License: GPL
Group: Development/Tools
Source: %{name}-%{version}.tar.gz
Source1: check-errors.sh
Source2: cairo-%{cairo_ver}.tar.gz
Source3: make-html.pl
Source4: text-rotate-ref.png
Patch0: lsb-xft-double-free.patch
Patch1: lsb-freetype-ft_select_size.patch
Patch2: lsb-xft-lsbcc-build.patch
Patch3: lsb-qt-build-with-423.patch
Patch4: lsb-qt-test-only-42-abi.patch
# https://bugs.freedesktop.org/show_bug.cgi?id=5136
Patch5: cairo-1.0.2-bug-5136.patch
Patch6: cairo-1.0.2-tetj.patch
Patch7: cairo-1.0.2-lsbcc.patch
Patch8: cairo-test-ft-font-create-for-ft-face-uplift.patch
Patch9: lsb-qt-bug-2515.patch
URL: http://www.linuxbase.org/test
#Prefix: %{_prefix}
BuildRoot: %{_tmppath}/%{name}-%{version}-root
AutoReqProv: no
Requires: lsb-tet3-lite >= 3.7
Requires: lsb-xvfb, lsb-python
BuildRequires: lsb-tet3-lite-devel, lsb-build-desktop >= 3.1.90, lsb-build-qt4 >= 3.1.90, lsb-build-qt3 >= 3.1.90
%define	tet_root	%{_libdir}/tet
# allow us to tune build for debugging issues
%define save_journal	1
# defined in Makefile
%define pwd		%{_sourcedir}
# set per overrides in rpmbuild command
%{?_without_savejournal: %{expand: %%global save_journal 0}}

%description
This the official package version of the LSB desktop test suites.

NOTE: See lsb-test-desktop-gtkvts-source for the C source code for 
      debugging gtkvts test issues

%package -n %{name}-gtkvts-source
Summary: LSB Desktop Test Suites GTKVTS Source
Group: Development/Documentation

%description -n %{name}-gtkvts-source
C source files from the lsb-gtkvts build, for failure debugging

#==================================================
%prep
set -x
%setup -q -a2
cd lsb-qt
%patch3 -p0 -b .423
%patch4 -p0 -b .42abi
%patch9 -p0 -b .bug-2515
cd ..
cd cairo-%{cairo_ver}
%patch5 -p0 -b .bug-5136
%patch6 -p0 -b .tetj
%patch7 -p0 -b .lsbcc
cd test
%patch8 -p0 -b .ft-font
cd ../..

#==================================================
%build
TET_ROOT=`pwd`
TET_PATH=/opt/lsb-tet3-lite
TOP=`pwd`
# see bug 1429, short version being that rpm doesn't force the PATH env var
# to include sbin, thus since we use useradd, we force it ourselves
# (section 16.4 of fhs/lsb core doc mandates /usr/local/sbin, 
# else it would be left out)
PATH=/opt/lsb/bin:$PATH:$TET_PATH/bin:/sbin:/usr/sbin:/usr/local/sbin/:
QMAKESPEC=/opt/lsb/mkspecs/linux-lsb
LSBCC_BESTEFFORT=1
export TET_ROOT TET_PATH PATH QMAKESPEC LSBCC_BESTEFFORT

# tetj wrappers used for qt4, xml, and cairo
cd ${TOP}/tetj
make

export CC=lsbcc CXX="lsbc++" LSB_PRODUCT=desktop 
for x in /opt/lsb/lib*/pkgconfig; do
	PKG_CONFIG_PATH="${x}${PKG_CONFIG_PATH+:${PKG_CONFIG_PATH}}"
done
export PKG_CONFIG_PATH

# cairo tests
cd ${TOP}/cairo-%{cairo_ver}
LSBHOME="${TOP}" ./configure 
# we want to build the tests, but not fail the build
# if test run fails
unset DISPLAY #(Xlib tests will just skip)
# this one always fails?
sed -i 's|text-antialias-none ||g' test/Makefile
# fails on most (all?) distributions
sed -i 's|path-data ||g' test/Makefile
# old test code fails on new cairo, new test code fails on old cairo
# it is simply a regression tests for a bug, disable it
sed -i 's|surface-finish-twice ||g' test/Makefile
# above 2 drops lower the test count by 4
sed -i 's|total tests in cairo 114|total tests in cairo 110|g' test/xlib-surface.c
# LSB bug 2747, Moblin bug 6137 - drop all the tests that warn about pixel diffs
for TEST in caps-joins caps-sub-paths clip-nesting clip-operator clip-twice \
	dash-caps-joins fill-and-stroke fill-rule gradient-alpha leaky-polygon \
	linear-gradient mask operator-clear operator-source \
	paint-with-alpha rectangle-rounding-error rel-path self-copy \
	set-source show-text-current-point \
	text-antialias-gray text-antialias-subpixel \
	text-pattern transforms trap-clip unantialiased-shapes \
	unbounded-operator; do
  sed -i "s|\t$TEST |\t|g" test/Makefile
  sed -i "s| $TEST | |g" test/Makefile
done
# this drops another 54 tests
sed -i 's|total tests in cairo 110|total tests in cairo 56|g' test/xlib-surface.c

LSBHOME="${TOP}" make check

# Qt3 tests
cd ${TOP}/lsb-qt3
LSBHOME="${TOP}" TET_SUITE_ROOT="${TET_ROOT}" TET_ROOT="${TET_PATH}" tcc -p -b lsb-qt3
%if %{save_journal}
  cp -f results/0001b/journal %{pwd}/qt3build.journal
%endif

# Qt4 tests
cd ${TOP}/lsb-qt

# need to figure out why this one does not build - skip for now
sed -i 's|qmetatype ||g' tests/tests.pro 

# these do not build with a qt4.2 toolchain
# patched these so we can get some tests
# If commented, they are patched, otherwise skipped
#sed -i 's|qatomic ||g' tests/tests.pro 
#sed -i 's|qchar ||g' tests/tests.pro 
#sed -i 's|qcolor ||g' tests/tests.pro 
#sed -i 's|qcoreapplication ||g' tests/tests.pro 
#sed -i 's|qdatawidgetmapper ||g' tests/tests.pro 
#sed -i 's|qdoublespinbox ||g' tests/tests.pro 
#sed -i 's|qdoublevalidator ||g' tests/tests.pro 
#sed -i 's|qgraphicsitemanimation ||g' tests/tests.pro 
#sed -i 's|qgridlayout ||g' tests/tests.pro 
#sed -i 's|qhash ||g' tests/tests.pro 
#sed -i 's|qheaderview ||g' tests/tests.pro 
#sed -i 's|qicon ||g' tests/tests.pro 
#sed -i 's|qintvalidator ||g' tests/tests.pro 
#sed -i 's|qlayout ||g' tests/tests.pro 
#sed -i 's|qlineedit ||g' tests/tests.pro 
#sed -i 's|qlistwidget ||g' tests/tests.pro 
#sed -i 's|qlocale ||g' tests/tests.pro 
#sed -i 's|qmap ||g' tests/tests.pro 
#sed -i 's|qnumeric ||g' tests/tests.pro 
#sed -i 's|qpainterpath ||g' tests/tests.pro 
#sed -i 's|qpixmap ||g' tests/tests.pro 
#sed -i 's|qreadwritelock ||g' tests/tests.pro 
#sed -i 's|qstandarditem ||g' tests/tests.pro 
#sed -i 's|qstandarditemmodel ||g' tests/tests.pro 
#sed -i 's|qstyle ||g' tests/tests.pro 
#sed -i 's|qtablewidget ||g' tests/tests.pro 
#sed -i 's|qtextdocumentfragment ||g' tests/tests.pro 
#sed -i 's|qtreeview ||g' tests/tests.pro 
#sed -i 's|qtreewidget ||g' tests/tests.pro 

# only one test, no need to patch
sed -i 's|qcomplextext ||g' tests/tests.pro

# header needed to build is not in 4.2.3 
sed -i 's|qdiriterator ||g' tests/tests.pro
sed -i 's|qmdiarea ||g' tests/tests.pro 
sed -i 's|qtransform ||g' tests/tests.pro 
sed -i 's|qwizard ||g' tests/tests.pro 

# even after patching out all but one test, this fails at link, drop it
sed -i 's|qpathclipper ||g' tests/tests.pro 

# private header qtextdocument_p.h is the problem here - patched
#sed -i 's|qtextblock ||g' tests/tests.pro 

# got "fixed" by a previous patch
#sed -i 's|qtextlayout ||g' tests/tests.pro 

# fails at link - 2 tests - drop it
sed -i 's|qwindowsurface ||g' tests/tests.pro 

# these segfault built with 4.2.3 - with or without lsbcc
sed -i 's|qbitarray ||g' tests/tests.pro
sed -i 's|qdrag ||g' tests/tests.pro
sed -i 's|qregexp ||g' tests/tests.pro
sed -i 's|qsortfilterproxymodel ||g' tests/tests.pro
sed -i 's|qsvgrenderer ||g' tests/tests.pro
sed -i 's|qtextblock ||g' tests/tests.pro
sed -i 's|qtreewidget ||g' tests/tests.pro

# this one never completes
sed -i 's|qreadwritelock ||g' tests/tests.pro

# same for these, on machines with low resources
sed -i 's|qrand ||g' tests/tests.pro
sed -i 's|qobjectrace ||g' tests/tests.pro

# tests that fail build using lsbc++
# more comments below in ## entries
## undefined reference to `QDialogButtonBox::staticMetaObject'
sed -i 's|qdialogbuttonbox ||g' tests/tests.pro
sed -i 's|qinputdialog ||g' tests/tests.pro

## needs qt_x11_wait_for_window_manager
sed -i 's|qabstractitemview ||g' tests/tests.pro
## unresolvable R_386_32 relocation against symbol
## `typeinfo for QCompleter' at final link 
sed -i 's|qcompleter ||g' tests/tests.pro
sed -i 's|qdockwidget ||g' tests/tests.pro
sed -i 's|qgridlayout ||g' tests/tests.pro
sed -i 's|qlistwidget ||g' tests/tests.pro
sed -i 's|qtoolbar ||g' tests/tests.pro

## undefined reference to `QPainterPath::detach_helper()'
sed -i 's|qpainterpath ||g' tests/tests.pro

## undefined reference to `qt_qscrollbarStyleOption(QScrollBar*)'
sed -i 's|qscrollbar ||g' tests/tests.pro
sed -i 's|qstyle ||g' tests/tests.pro

##  unresolvable R_386_32 relocation against symbol
## `typeinfo for QStandardItem' at final link
sed -i 's|qstandarditemmodel ||g' tests/tests.pro

## complains about /opt/lsb/include/private/qlayoutengine_p.h (part of qt3?)
#sed -i 's|../QtTest|../QtTest ../QtTest/private|g' tests/tests.pri
sed -i 's|qlayout ||g' tests/tests.pro
 
## using /opt/lsb/include/private/qfontdata_p.h
sed -i 's|qtextlayout ||g' tests/tests.pro

## using /opt/lsb/include/private/qunicodetables_p.h
sed -i 's|qchar ||g' tests/tests.pro

## undefined reference to `QTreeWidgetItem::itemChanged()'
sed -i 's|qtreewidgetitemiterator ||g' tests/tests.pro

# this one says it can't load the translation during test 5 
# built with lsbcc, worked when we were still using gcc
sed -i 's|qtranslator ||g' tests/tests.pro

LSBHOME="${TOP}" /opt/lsb/bin/qmake_lsb_qt4 -spec /opt/lsb/mkspecs/linux-lsb
LSBHOME="${TOP}" make

# make xrender, freetype and xft test binaries
cd ${TOP}
tcc -b -p lsb-xrender
%if %{save_journal}
  cp -f lsb-xrender/results/0001b/journal %{pwd}/xrenderbuild.journal
%endif
tcc -b -p lsb-freetype
%if %{save_journal}
  cp -f lsb-freetype/results/0001b/journal %{pwd}/freetypebuild.journal
%endif
# test_base uses FT_Select_Size - which isn't in SLES10 version
# also does not build against libbat libfreetype.a
# once this function is removed, lsbcc works
# (tarball Makefile had hardcoded gcc for link stage)
# just re-run make as tcc will unpack the tarball again
cd lsb-freetype
patch -p0 -b -z .ft_select_size < %{PATCH1}
# since we are rebuilding, drop bad journal
rm -f results/0001b/journal
cd ..
# and rebuild
CC=lsbcc make -C lsb-freetype/tests/test

tcc -b -p lsb-xft
%if %{save_journal}
  cp -f lsb-xft/results/0001b/journal %{pwd}/xftbuild.journal
%endif
# tcc build has issues - fix and rebuild
# unit.4 crashes with a double free - patch it
cd lsb-xft
patch -p0 -b -z .double-free < %{PATCH0}
# sigh, this one also has a hardcoded gcc and uses non-LSB functions
# (XftNameUnparse, getline)
patch -p0 -b -z .lsbcc < %{PATCH2}
# since we are rebuilding, drop bad journal
rm -f results/0001b/journal
cd ..
# fix hard coded /lib reference for xft, have to do it 
# after tcc runs because the source is tarballed up
%ifarch ppc64 s390x x86_64
sed -i 's|X11R6/lib|X11R6/lib64|g' lsb-xft/tests/test/Makefile
%endif
# and rebuild
CC=lsbcc make -C lsb-xft/tests/test

# the gtkvts part
cd ${TOP}/lsb-gtkvts
# try to catch code issues that fall down on some archs
# with GTKVTS_CFLAGS - add -Werror if you really want to break on warnings
# -Wuninitialized wants -Ox, 
# -O2 causes regression in GtkProgressBar, so use -O0
#CC="lsbcc -O0 -Wuninitialized -Werror"
#GTKVTS_CFLAGS="-O0 -Wuninitialized -Werror `pkg-config --cflags gtk+-2.0`" PATH=$PWD/deps/bin:$PATH ACLOCAL_FLAGS="-I $PWD/deps/share/aclocal $ACLOCAL_FLAGS" ./autogen.sh --with-no-hdr-tests=TRUE --with-no-doc-parsing=TRUE
CC="lsbcc -O0 -Wuninitialized"
GTKVTS_CFLAGS="-O0 -Wuninitialized `pkg-config --cflags gtk+-2.0`" PATH=$PWD/deps/bin:$PATH ACLOCAL_FLAGS="-I $PWD/deps/share/aclocal $ACLOCAL_FLAGS" ./autogen.sh --with-no-hdr-tests=TRUE --with-no-doc-parsing=TRUE
make

cd ${TOP}
tcc -b -p lsb-gtkvts
%if %{save_journal}
  cp -f lsb-gtkvts/results/0001b/journal %{pwd}/gtkvtsbuild.journal
%endif


# and now verify it didn't fail since tcc doesn't report build errors in tests.
set +x
failed=
cd ${TOP}/lsb-gtkvts/tests/functions
for x in *; do 
	[ ! -e "$x/makefile" ] && continue		
	if [ ! -e "$x/$x" ]; then 
		echo "failed building gtkvts sub test $x"
		failed=1
	fi
done
set -x
[ -n "$failed" ] && exit 1

# the xml part
cd ${TOP}/lsb-xml/lsb-xml2
LSBHOME=${TOP} make -f Makefile.tests

# libpng tests
cd ${TOP}/lsb-libpng
LSBHOME=${TOP} make -f Makefile
cd ..

# thanks to the magic of tcc, we can merrily build the package 
# and have hidden compile problems - survey the journals and
# bail if we see 'Error 2'. Cat the offending journals so we
# can troubleshoot from the autobuild logs

sh %{SOURCE1}

#==================================================
%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/bin

cp -pf scripts/runtime/run_tests ${RPM_BUILD_ROOT}/opt/lsb/test/desktop
sed -i -e 's:^BUILD_VERSION=$:BUILD_VERSION=%{version}:' ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/run_tests
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/run_tests
cp -pf scripts/runtime/editcfg.sh ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/bin
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/bin/editcfg.sh

# move %%post console message to README (bug 1940)
cat > README.%{name} << EOF
To run the tests, please execute the following command:
    cd /opt/lsb/test/desktop; ./run_tests

You will need to run the tests as root.
EOF

# licensing
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
for lfile in License Artistic GPL README.%{name}; do cp -pf ${lfile} ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}; done

# the gtkvts part
cd lsb-gtkvts
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Widgets
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Resource_Files
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/picfile
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/tmpfile
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Glib
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/scenarios
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/results

cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tet_scen
cp -pf scenarios/func_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/scenarios/func_scen

for file in `find tests/functions -perm 755`; do
	dir_name=`dirname $file`
        mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/$dir_name
	cp -pf $file ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/$dir_name
done

#some special test cases need the following files
install -D -m644 tests/functions/FileUtil/FileUtil.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/FileUtil/FileUtil.c
install -D -m644 tests/functions/GIOChannel/GIOChannel.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/GIOChannel/GIOChannel.c
install -D -m644 tests/functions/GtkFileSelection/GtkFileSelection.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/GtkFileSelection/GtkFileSelection.c
cp -pf src/tests/functions/Widgets/gnome-logo-icon.png ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png
cp -pf src/tests/functions/Widgets/MyUI.xml ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Widgets/MyUI.xml
cp -pf src/tests/functions/Resource_Files/rc_example.rc ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Resource_Files/rc_example.rc
cp -prf src/tests/functions/GdkPixbuf/picfile/ ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/
cp -prf src/tests/functions/GdkPixbuf/tmpfile/ ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/
cp -prf src/tests/functions/Glib/casefold.txt ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Glib/casefold.txt
cp -prf src/tests/functions/Glib/casemap.txt ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Glib/casemap.txt
cd ..

# fontconfig files and directories
cd lsb-fontconfig
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/fonts
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tc
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/results

cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tet_scen
cp -pf fonts.conf ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/fonts.conf
cp -pf out.expected ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/out.expected
cp -prf fonts ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/
cp -prf tc ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tc/tc1
cd ..

# xrender files and directories
cd lsb-xrender
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender/tests
cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender/tet_scen
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender/tests/rendercheck-1.1
cp -pf tests/tc* ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender/tests
cp -pf tests/rendercheck-1.1/rendercheck ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xrender/tests/rendercheck-1.1
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/man/man1
cp -pf tests/rendercheck-1.1/rendercheck.1 ${RPM_BUILD_ROOT}/opt/lsb/man/man1
cd ..

# freetype files and directories
cd lsb-freetype
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype/tests

cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype/tet_scen
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype/tests/test
cp -pf tests/tc* ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype/tests
cp -pf tests/test/test_{base,bbox,list,trig} ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/freetype/tests/test
cd ..

# xft files and directories
cd lsb-xft
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tests

cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tet_scen
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tests/test
cp -pf tests/tc* ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tests
cp -pf tests/test/unit.{1,2,3,4} ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tests/test
cp -pf tests/test/utf8test.txt ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xft/tests/test
cd ..

# the xml part
cd lsb-xml/lsb-xml2
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/result
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/test

cp -pf lsb-rt-libxml2 ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/lsb-rt-libxml2
cp -pf runtest ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -pf testapi ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -prf result ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -prf test ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cd ../..

# libpng
cd lsb-libpng
mkdir -p "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/results"
mkdir -p "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/test"

cp -rpf imageSuite "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/"
install -m755 lsb-rt-libpng runtest "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/"
cd ..

# qt4
cd lsb-qt
for x in `find tests -type f -perm 755`; do
	install -D -m755 "$x" "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/$x"
done
cp -pf tet_scen "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/"
cp -pf tetexec.cfg "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/"
install -m755 lsb-rt-qt "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt"
cp -pf fix-qt-journal.awk "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt"

# needed for qtranslator tests
#install tests/qtranslator/hellotr_la.* ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/tests/qtranslator
# and qpixmap
cp -pr tests/qpixmap/convertFromImage ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/tests/qpixmap
# and qfontdatabase
cp -pr tests/qfontdatabase/FreeMono.ttf ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/tests/qfontdatabase
# and qicon
cp -p tests/qicon/image.* ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/tests/qicon
cp -p tests/qicon/rect.png ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/tests/qicon
cd ..

# qt3; install all tet_scen specified tests.
cd lsb-qt3
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/ts
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/ts/tests
for x in `find ts/tests -type f -perm 755`; do
	echo $x
	install -D -m755 $x "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/$x"
done
cp -pf tet_scen "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/tet_scen"
cp -pf tetexec.cfg "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/tetexec.cfg"
cd ..

# menu/spec.  pretty simple.
cd lsb-fdo
cp -rpf desktop-test menu-spec ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/
cd ..

# gtkvts c source
mkdir ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}/lsb-gtkvts-source
pushd lsb-gtkvts
find tests -name '*.c' | xargs -i cp --parents {} ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}/lsb-gtkvts-source
popd 

# cairo
cd cairo-%{cairo_ver}/test
echo '#!/bin/sh' > cairo-tests.sh 
make -n run-TESTS | grep -v '^make' >> cairo-tests.sh
# user data is just a bunch of asserts, did not try to tet'ify it
sed -i 's|user-data||g' cairo-tests.sh
# concatenate the test journals
cat << EOF >> cairo-tests.sh
journal="journal.cairo"
if test -n "\$list"; then
  rm -f "\$journal" 
  for tst in \$list; do
    # bug 2735 - now we have seperate journals 
    # for image and xlib, need to collect both
    if [ -f "journal.\$tst-image" ];then
      cat "journal.\$tst-image" >> "\$journal"
      rm -f "journal.\$tst-image"
    fi
    if [ -f "journal.\$tst-xlib" ];then
      cat "journal.\$tst-xlib" >> "\$journal"
      rm -f "journal.\$tst-xlib"
    fi
    if [ -f "journal.\$tst" ];then
      cat "journal.\$tst" >> "\$journal"
      rm -f "journal.\$tst"
    fi
  done
fi
EOF
chmod +x cairo-tests.sh
# install the tests and test data
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/cairo
cp cairo-tests.sh ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/cairo
rm -f *-out.png *-diff.png
cp *.png ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/cairo
rm -f .libs/*.o
cp .libs/* ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/cairo
cd ..
# 1.0.2 didn't have make-html.pl - cobbled together one to help with
# getting cairo community input on test failures
cp %{SOURCE3} ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/cairo
# missing in 1.0.2 tarball
cp %{SOURCE4} ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/cairo
# and the license files
cp COPYING ${RPM_BUILD_ROOT}/opt/lsb/doc/lsb-test-desktop/COPYING.cairo
cp COPYING-LGPL-2.1 ${RPM_BUILD_ROOT}/opt/lsb/doc/lsb-test-desktop/COPYING-LGPL-2.1.cairo
cp COPYING-MPL-1.1 ${RPM_BUILD_ROOT}/opt/lsb/doc/lsb-test-desktop/COPYING-MPL-1.1.cairo
cd ..

#==================================================
%clean
rm -rf ${RPM_BUILD_ROOT}

#======================================================================
%pre
# Need to create some group and user beforehand because
# some test cases must run as non-root user.
groupadd lsb-desktop > /dev/null 2>&1 || true
useradd -g lsb-desktop lsb-desktop > /dev/null 2>&1 || true

#======================================================================
%post
for i in .configured .start_test;do
  if [ -e /opt/lsb/test/desktop/$i ]; then
	rm -f /opt/lsb/test/desktop/$i  > /dev/null 2>&1 || true
  fi
done

#======================================================================
%postun
if [ "$1" = "0" ] ; then # last uninstall
  userdel lsb-desktop > /dev/null 2>&1 || true
  groupdel lsb-desktop > /dev/null 2>&1 || true

  if [ -e /home/lsb-desktop ]; then
	rm -rf /home/lsb-desktop > /dev/null 2>&1 || true
  fi
fi

#==================================================
%files
%defattr(-,root,root)

/opt/lsb/test/desktop/run_tests
/opt/lsb/test/desktop/bin
%dir /opt/lsb/doc/%{name}
/opt/lsb/doc/lsb-test-desktop/Artistic
/opt/lsb/doc/lsb-test-desktop/GPL
/opt/lsb/doc/lsb-test-desktop/License
/opt/lsb/doc/lsb-test-desktop/README.%{name}

# the gtkvts part
%config(noreplace) /opt/lsb/test/desktop/gtkvts/tetexec.cfg

/opt/lsb/test/desktop/gtkvts/tet_scen
/opt/lsb/test/desktop/gtkvts/scenarios
/opt/lsb/test/desktop/gtkvts/tests
/opt/lsb/test/desktop/gtkvts/src

%dir /opt/lsb/test/desktop/gtkvts/results

# fontconfig
%config(noreplace) /opt/lsb/test/desktop/fontconfig/tetexec.cfg

/opt/lsb/test/desktop/fontconfig/tet_scen
/opt/lsb/test/desktop/fontconfig/fonts.conf
/opt/lsb/test/desktop/fontconfig/out.expected
/opt/lsb/test/desktop/fontconfig/tc
/opt/lsb/test/desktop/fontconfig/fonts

%dir /opt/lsb/test/desktop/fontconfig/results

# xrender
%config(noreplace) /opt/lsb/test/desktop/xrender/tetexec.cfg

/opt/lsb/test/desktop/xrender/tet_scen
/opt/lsb/test/desktop/xrender/tests
/opt/lsb/man/man1/rendercheck.1

# freetype
%config(noreplace) /opt/lsb/test/desktop/freetype/tetexec.cfg

/opt/lsb/test/desktop/freetype/tet_scen
/opt/lsb/test/desktop/freetype/tests

# xft
%config(noreplace) /opt/lsb/test/desktop/xft/tetexec.cfg
/opt/lsb/test/desktop/xft/tet_scen
/opt/lsb/test/desktop/xft/tests

# the xml part
/opt/lsb/test/desktop/xml/lsb-rt-libxml2
/opt/lsb/test/desktop/xml/runtest
/opt/lsb/test/desktop/xml/testapi
/opt/lsb/test/desktop/xml/result
/opt/lsb/test/desktop/xml/test

# png
/opt/lsb/test/desktop/libpng/lsb-rt-libpng
/opt/lsb/test/desktop/libpng/runtest
/opt/lsb/test/desktop/libpng/test
%dir /opt/lsb/test/desktop/libpng/imageSuite
/opt/lsb/test/desktop/libpng/imageSuite/*

# Qt4
%dir /opt/lsb/test/desktop/Qt
%config(noreplace) /opt/lsb/test/desktop/Qt/tetexec.cfg
/opt/lsb/test/desktop/Qt/*

# Qt3
/opt/lsb/test/desktop/qt3/tet_scen
%config(noreplace) /opt/lsb/test/desktop/qt3/tetexec.cfg
%dir /opt/lsb/test/desktop/qt3/ts
%dir /opt/lsb/test/desktop/qt3/ts/tests/
/opt/lsb/test/desktop/qt3/ts/tests/*

# menu/spec
%dir /opt/lsb/test/desktop/menu-spec
%config(noreplace) /opt/lsb/test/desktop/menu-spec/tetexec.cfg
/opt/lsb/test/desktop/menu-spec/*

%dir /opt/lsb/test/desktop/desktop-test
%config(noreplace) /opt/lsb/test/desktop/desktop-test/tetexec.cfg
/opt/lsb/test/desktop/desktop-test/*

# cairo
%dir /opt/lsb/test/desktop/cairo
/opt/lsb/test/desktop/cairo/*
/opt/lsb/doc/lsb-test-desktop/COPYING*.cairo

%files -n %{name}-gtkvts-source
%defattr(-,root,root)
%dir /opt/lsb/doc/%{name}/lsb-gtkvts-source
/opt/lsb/doc/%{name}/lsb-gtkvts-source/*

#==================================================
%changelog
* Fri Oct 09 2009 Stew Benedict <stewb@linux-foundation.org>
- drop all the cairo tests that warn about pixel diffs (bug 2747)

* Fri Jun 05 2009 Stew Benedict <stewb@linux-foundation.org>
- add P9 to fix qt4 tests that fail against 4.2.1 (bug 2515)

* Tue Oct 28 2008 Stew Benedict <stewb@linux-foundation.org>
- disable path-data and surface-finish-twice tests in Cairo (bug 2353)

* Tue Aug 19 2008 Stew Benedict <stewb@linux-foundation.org>
- partially uplift ft-font-create-for-ft-face to 1.6.4 so it 
  works on more systems (P8)
- handle early fails of path-data (update P6): 
  get fail mode to journal and record as UNREPORTED

* Fri Aug 15 2008 Stew Benedict <stewb@linux-foundation.org>
- cairo test mods
  add make-html.pl (debugging aid, S3), 
  text-rotate-ref.png (missing in 1.0.2, borrowed from 1.4.14, S4)

* Tue Aug 12 2008 Stew Benedict <stewb@linux-foundation.org>
- build cairo tests with lsbcc too (P7)
- break out cairo test build from test run (P6)

* Thu Aug 07 2008 Stew Benedict <stewb@linux-foundation.org>
- add cairo tests (S2, P5,P6)

* Thu Feb 21 2008 Stew Benedict <stewb@linux-foundation.org>
- define version in the Makefile
- move %%post console messages to README.%{name} (bug 1940)

* Thu Jan 17 2008 Stew Benedict <stewb@linux-foundation.org>
- fix bug 1892
  QIcon test uses hard-coded paths from the build dir (add to P3)
  required image files weren't packaged

* Thu Dec 20 2007 Stew Benedict <stewb@linux-foundation.org>
- make all 9 tetexec.cfg files %%config(noreplace)
- move GtkWindow tests 35-38 to the end of the set (bug 1851)

* Wed Dec 19 2007 Stew Benedict <stewb@linux-foundation.org>
- fix qt4 journal (bug 1850)

* Wed Dec 19 2007 Stew Benedict <stewb@linux-foundation.org>
- requires lsb-python (bug 1849)
- bump build-requires to >= 3.1.90, instead of 3.0.0

* Mon Dec 17 2007 Stew Benedict <stewb@linux-foundation.org>
- disable more tests that fail on < 4.3 (P4)

* Tue Dec 11 2007 Stew Benedict <stewb@linux-foundation.org>
- disable Qt4 qrand, qobjectrace - do not complete on many platforms
- install FreeMono.ttf for qfontdatabase

* Tue Nov 20 2007 Stew Benedict <stewb@linux-foundation.org>
- document reasons for non-builds

* Mon Nov 19 2007 Stew Benedict <stewb@linux-foundation.org>
- back to LSB toolchain
  pull some bits from upstream tarball to facilitate build
  disable some more tests (temporarily) that do not build with lsbcc
  link with libz (added bits above need it)

* Thu Nov 15 2007 Stew Benedict <stewb@linux-foundation.org>
- patch/drop qt4 tests that have issues building with 4.2.3 (P3)

* Mon Nov 12 2007 Stew Benedict <stewb@linux-foundation.org>
- update qt4 tests - use gcc rather than lsbcc until toolchain
  catches up

* Fri Jul 27 2007 Stew Benedict <stewb@linux-foundation.org>
- turn rendercheck install back on again - seems like it's being built

* Wed Jul 25 2007 Stew Benedict <stewb@linux-foundation.org>
- drop journals we know are bad before the audit
- lsb-xft has hardcoded gcc too, and needs -lfontconfig (P2)
- lsb-xft uses XftNameUnparse, getline - not in LSB (P2)
- disable XftNameUnparse test and borrow getline.c from leafnode
- re-group the rebuilds with the initial test build

* Tue Jul 24 2007 Stew Benedict <stewb@linux-foundation.org>
- use lsbcc for freetype tests (rework P1)
- survey journals for errors and exit build if found

* Tue Jul 24 2007 Mats Wichmann <mats@linux-foundation.org>
- save tcc build journals in case debugging is needed

* Mon Jul 23 2007 Stew Benedict <stewb@linux-foundation.org>
- partially undo the xrender workaround
  (autobuilds failing now on ppc64, s390)

* Wed Jul 11 2007 Stew Benedict <stewb@linux-foundation.org>
- workaround xrender, freetype non-builds (#1593)
  use gcc instead of lsbcc for the moment
  add P1 for freetype (do not use FT_Select_Size)
- tweak the %%install stanzas for xrender, freetype

* Thu Apr 05 2007 Stew Benedict <stewb@aysenterprises.com>
- #1575 - build an gtkvts-source subpackage to aid debugging

* Wed Apr 04 2007 Mats Wichmann <mats@freestandards.org>
- #1584 - (based on patch from Stew Benedict) - rework run_tests
to allow running a single test suite and other cleanup. Qt4
is also now standard, rather than optional

* Wed Jan 31 2007 Mats Wichmann <mats@freestandards.org>
- #1562 - revert; new fix is to result reporting in xml-test code

* Tue Jan 30 2007 Stew Benedict <stewb@aysenterprises.com>
- #1562 - fix XML_0 57 (add symlink to test/title.xml)

* Sat Jan 27 2007 Stew Benedict <stewb@aysenterprises.com>
- clean up .configured, .start_test
- offer to show test report
- find the latest journals instead of {max}e
- fix upgrade scenario so we don't remove lsb-desktop user
- add test counts to xml, libpng, qt3, and fontconfig tests
- use RELEASE tag from Makefile
- make run_tests sh compliant

* Tue Dec 12 2006 Mats Wichmann
- rework for bzr version control, 3.1.1 release

* Mon Dec 4 2006 Tracy Camp
- Add freetype

* Mon Nov 11 2006 Tracy Camp
- Add xrender

* Thu May 25 2006 Marvin Heffler
- Increment release number to 10 for official respin of test package

* Fri May 19 2006 Marvin Heffler
- Increment release number to 9 due to rebuild with newer tet package

* Mon Apr 24 2006 Marvin Heffler
- Add /opt/lsb/doc directory to files list so it gets packaged

* Tue Feb 28 2006 Marvin Heffler
- Removed duplicate entry for tests subdirectory of Qt
